# pyLearnAlgorithms
This package was developed as one of the results of a research project developed at the Federal University of Campina Grande.

## Getting Started
#### Dependencies
You need Python 3.6 or later to use **pyLearnAlgorithms**. You can find it at [python.org](https://www.python.org/).

You also need numpy, scipy, pandas and matplotlib packages. If you have pip, just run:
```
pip install numpy
pip install scipy
pip install pandas
ip install matplotlib
```

## Installation
install the package via PiP, use the following command:
```
pip install pyLearnAlgorithms
```

## Update
To update the package, use the following command via PIP:
```
pip install pyLearnAlgorithms --update
```

## Features
```
- [x] Solving linear regression problems
- [x] Solving polynomial regression problems
- [x] Open data on different formats
- [x] Split data into training, validation and testing
- [x] Several examples available for learning
- [x] Setup with package informations
- [x] License example
```